@@ -1,3 +1,5 @@
+"""Runtime error handling middleware for FastAPI applications."""
+
 from typing import Any, Callable, Dict
 
 from fastapi import Request, Response
@@ -74,7 +76,7 @@ class Runtime:
             payload = await self.create_payload(request, e)
             try:
                 message = str(e)
-            except:
+            except Exception:
                 message = "Unrecognized Error has happened."
 
             footprint.leave(
