@@ -92,10 +92,12 @@ def auth_data_class_to_dependency(authentication: Auth) -> List[Depends]:
         )
         return [
             Depends(checker),
-            Depends(APIKeyHeader(
-                name=authentication.header_key,
-                description=f"API key header '{authentication.header_key}' required for access."
-            )),
+            Depends(
+                APIKeyHeader(
+                    name=authentication.header_key,
+                    description=f"API key header '{authentication.header_key}' required for access.",
+                )
+            ),
         ]
     elif authentication.auth_type == AuthType.QUERY:
         checker = QueryAuthChecker(
@@ -103,10 +105,12 @@ def auth_data_class_to_dependency(authentication: Auth) -> List[Depends]:
         )
         return [
             Depends(checker),
-            Depends(APIKeyQuery(
-                name=authentication.header_key,
-                description=f"API key query parameter '{authentication.header_key}' required for access."
-            )),
+            Depends(
+                APIKeyQuery(
+                    name=authentication.header_key,
+                    description=f"API key query parameter '{authentication.header_key}' required for access.",
+                )
+            ),
         ]
 
     return []
