@@ -1,7 +1,7 @@
 from datetime import date, datetime
 from typing import List
 
-from pydantic import BaseModel, ConfigDict, field_validator, Field
+from pydantic import BaseModel, ConfigDict, Field, field_validator
 
 from ...core.enums import OrderingType
 
@@ -19,13 +19,10 @@ __all__ = (
 class Sorting(BaseModel):
     """Sorting configuration for query results."""
 
-    sort_by: str = Field(
-        ...,
-        description="The field name to sort results by."
-    )
+    sort_by: str = Field(..., description="The field name to sort results by.")
     order_by: OrderingType = Field(
         default=OrderingType.asc,
-        description="Sorting direction: ascending or descending."
+        description="Sorting direction: ascending or descending.",
     )
 
 
@@ -33,20 +30,16 @@ class SearchPayload(BaseModel):
     """Common request payload for paginated and searchable list endpoints."""
 
     page: int | None = Field(
-        default=1,
-        description="Page number to retrieve (must be >= 1)."
+        default=1, description="Page number to retrieve (must be >= 1)."
     )
     items_per_page: int | None = Field(
-        default=20,
-        description="Number of items per page (max 30)."
+        default=20, description="Number of items per page (max 30)."
     )
     sorting: List[Sorting] | None = Field(
-        default=None,
-        description="Optional list of sorting rules applied to the query."
+        default=None, description="Optional list of sorting rules applied to the query."
     )
     search: str | None = Field(
-        default="",
-        description="Optional search term to filter results."
+        default="", description="Optional search term to filter results."
     )
 
     # Page number must be greater than or equal to one
@@ -71,12 +64,10 @@ class NumberRange(BaseModel):
     """Range filter for numeric values."""
 
     min: int | None = Field(
-        default=None,
-        description="Minimum value allowed in the range."
+        default=None, description="Minimum value allowed in the range."
     )
     max: int | None = Field(
-        default=None,
-        description="Maximum value allowed in the range."
+        default=None, description="Maximum value allowed in the range."
     )
 
 
@@ -84,12 +75,10 @@ class TimeRange(BaseModel):
     """Range filter for time values."""
 
     min: datetime | None = Field(
-        default=None,
-        description="Minimum datetime allowed in the range."
+        default=None, description="Minimum datetime allowed in the range."
     )
     max: datetime | None = Field(
-        default=None,
-        description="Maximum datetime allowed in the range."
+        default=None, description="Maximum datetime allowed in the range."
     )
 
 
@@ -97,12 +86,10 @@ class DateRange(BaseModel):
     """Range filter for date values."""
 
     min: date | None = Field(
-        default=None,
-        description="Minimum date allowed in the range."
+        default=None, description="Minimum date allowed in the range."
     )
     max: date | None = Field(
-        default=None,
-        description="Maximum date allowed in the range."
+        default=None, description="Maximum date allowed in the range."
     )
 
 
@@ -116,14 +103,11 @@ class ListPayloadResponse(BaseModel):
     """Standard response structure for paginated list endpoints."""
 
     total_row: int | None = Field(
-        default=None,
-        description="Total number of rows matching the query."
+        default=None, description="Total number of rows matching the query."
     )
     last_page: int | None = Field(
-        default=None,
-        description="The index of the last available page."
+        default=None, description="The index of the last available page."
     )
     has_next: bool | None = Field(
-        default=None,
-        description="Indicates if there is a next page available."
+        default=None, description="Indicates if there is a next page available."
     )
