@@ -1,7 +1,6 @@
-import boto3
-
 """Simple wrapper around boto3 S3 client."""
 
+import boto3
 from botocore.client import BaseClient
 from botocore.exceptions import ClientError, NoCredentialsError
 
@@ -67,7 +66,7 @@ class Bucket:
                 message="S3 credentials error",
                 status_code=500,
             )
-        except:
+        except Exception:
             return False
 
     def upload(
