@@ -1,8 +1,7 @@
 """Helpers for bridging async and sync code."""
 
-from typing import Awaitable, Any
 import asyncio
-
+from typing import Any, Awaitable
 
 __all__ = ("async_to_sync",)
 
