@@ -1,7 +1,6 @@
 """Utility helpers for safe attribute/function access."""
 
-from typing import Callable, Any
-
+from typing import Any, Callable
 
 __all__ = (
     "safe_access",
